==> kubernetes-model-4.1.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/VolumeDeviceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class VolumeDeviceFluentImpl<A extends VolumeDeviceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements VolumeDeviceFluent<A>{

    private String devicePath;
    private String name;

    public VolumeDeviceFluentImpl(){
    }
    public VolumeDeviceFluentImpl(VolumeDevice instance){
            this.withDevicePath(instance.getDevicePath()); 
            this.withName(instance.getName()); 
    }

    public String getDevicePath(){
            return this.devicePath;
    }

    public A withDevicePath(String devicePath){
            this.devicePath=devicePath; return (A) this;
    }

    public Boolean hasDevicePath(){
            return this.devicePath != null;
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            VolumeDeviceFluentImpl that = (VolumeDeviceFluentImpl) o;
            if (devicePath != null ? !devicePath.equals(that.devicePath) :that.devicePath != null) return false;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            return true;
    }




}

==> kubernetes-model-4.9.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/VolumeDeviceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class VolumeDeviceFluentImpl<A extends VolumeDeviceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements VolumeDeviceFluent<A>{

    private String devicePath;
    private String name;

    public VolumeDeviceFluentImpl(){
    }
    public VolumeDeviceFluentImpl(VolumeDevice instance){
            this.withDevicePath(instance.getDevicePath()); 
            this.withName(instance.getName()); 
    }

    public String getDevicePath(){
            return this.devicePath;
    }

    public A withDevicePath(String devicePath){
            this.devicePath=devicePath; return (A) this;
    }

    public Boolean hasDevicePath(){
            return this.devicePath != null;
    }

    public A withNewDevicePath(String arg1){
            return (A)withDevicePath(new String(arg1));
    }

    public A withNewDevicePath(StringBuilder arg1){
            return (A)withDevicePath(new String(arg1));
    }

    public A withNewDevicePath(StringBuffer arg1){
            return (A)withDevicePath(new String(arg1));
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public A withNewName(String arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1){
            return (A)withName(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            VolumeDeviceFluentImpl that = (VolumeDeviceFluentImpl) o;
            if (devicePath != null ? !devicePath.equals(that.devicePath) :that.devicePath != null) return false;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            return true;
    }




}
